@@ -31,7 +31,6 @@ class ProjectHolder(requests.Session):
     # web accessible project holders may have single well-known domain usable by everyone
     # in case of GitHub, that is github.com, for Mercurial web gui - here isn't one, etc.
     DEFAULT_HOSTNAME = None
-    DEFAULT_HOLDER = False
     KNOWN_REPO_URLS = {}
     KNOWN_REPOS_BY_NAME = {}
     # e.g. owner/project, but mercurial just /project together with hostname
@@ -65,6 +64,7 @@ class ProjectHolder(requests.Session):
         log.info('Created instance of {}'.format(type(self).__name__))
         self.branches = None
         self.only = None
+        self.exclude = None
         self.having_asset = None
         self.hostname = None
         # identifies project on a given hostname
@@ -87,12 +87,21 @@ class ProjectHolder(requests.Session):
         self.only = only
         if only:
             log.info('Only considering tags with "{}"'.format(only))
+        return self
+
+    def set_exclude(self, exclude):
+        """Sets "exclude" tag selector for this holder."""
+        self.exclude = exclude
+        if exclude:
+            log.info('Only considering tags without "{}"'.format(exclude))
+        return self
 
     def set_having_asset(self, having_asset):
         """Sets "having_asset" selector for this holder."""
         self.having_asset = having_asset
         if having_asset:
             log.info('Only considering releases with asset "{}"'.format(having_asset))
+        return self
 
     @classmethod
     def get_host_repo_for_link(cls, repo):
@@ -148,16 +157,22 @@ class ProjectHolder(requests.Session):
     def matches_only(self, version_s):
         if not self.only:
             return True
-        if self.only not in version_s:
-            log.info('"{}" does not match the "only" constraint "{}"'.format(version_s, self.only))
-            return False
-        return True
+        search = self.only
+        positive = True
+        if search.startswith('!'):
+            positive = False
+            search = search[1:]
+        if search.startswith('~'):
+            search = r'{}'.format(self.only.lstrip('~'))
+            return positive == bool(re.search(search, version_s))
+        return positive == bool(search in version_s)
 
     def sanitize_version(self, version_s, pre_ok=False, major=None):
         """Extract version from tag name."""
         log.info("Sanitizing string {} as a satisfying version.".format(version_s))
         res = False
         if not self.matches_only(version_s):
+            log.info('"{}" does not match the "only" constraint "{}"'.format(version_s, self.only))
             return res
         try:
             char_fix_required = self.repo in self.LAST_CHAR_FIX_REQUIRED_ON
